==> zio-aws-lightsail_2.12-5.17.206.1-sources.jar: zio/aws/lightsail/model/NetworkProtocol.scala <==
package zio.aws.lightsail.model
import scala.jdk.CollectionConverters._
sealed trait NetworkProtocol {
  def unwrap: software.amazon.awssdk.services.lightsail.model.NetworkProtocol
}
object NetworkProtocol {
  def wrap(
      value: software.amazon.awssdk.services.lightsail.model.NetworkProtocol
  ): zio.aws.lightsail.model.NetworkProtocol = value match {
    case software.amazon.awssdk.services.lightsail.model.NetworkProtocol.UNKNOWN_TO_SDK_VERSION =>
      val r = unknownToSdkVersion
      r
    case software.amazon.awssdk.services.lightsail.model.NetworkProtocol.TCP =>
      val r = tcp
      r
    case software.amazon.awssdk.services.lightsail.model.NetworkProtocol.ALL =>
      val r = all
      r
    case software.amazon.awssdk.services.lightsail.model.NetworkProtocol.UDP =>
      val r = udp
      r
    case software.amazon.awssdk.services.lightsail.model.NetworkProtocol.ICMP =>
      val r = icmp
      r
  }
  case object unknownToSdkVersion
      extends zio.aws.lightsail.model.NetworkProtocol {
    override def unwrap
        : software.amazon.awssdk.services.lightsail.model.NetworkProtocol =
      software.amazon.awssdk.services.lightsail.model.NetworkProtocol.UNKNOWN_TO_SDK_VERSION
  }
  case object tcp extends zio.aws.lightsail.model.NetworkProtocol {
    override def unwrap
        : software.amazon.awssdk.services.lightsail.model.NetworkProtocol =
      software.amazon.awssdk.services.lightsail.model.NetworkProtocol.TCP
  }
  case object all extends zio.aws.lightsail.model.NetworkProtocol {
    override def unwrap
        : software.amazon.awssdk.services.lightsail.model.NetworkProtocol =
      software.amazon.awssdk.services.lightsail.model.NetworkProtocol.ALL
  }
  case object udp extends zio.aws.lightsail.model.NetworkProtocol {
    override def unwrap
        : software.amazon.awssdk.services.lightsail.model.NetworkProtocol =
      software.amazon.awssdk.services.lightsail.model.NetworkProtocol.UDP
  }
  case object icmp extends zio.aws.lightsail.model.NetworkProtocol {
    override def unwrap
        : software.amazon.awssdk.services.lightsail.model.NetworkProtocol =
      software.amazon.awssdk.services.lightsail.model.NetworkProtocol.ICMP
  }
}

==> zio-aws-lightsail_2.12-7.28.29.1-sources.jar: zio/aws/lightsail/model/NetworkProtocol.scala <==
package zio.aws.lightsail.model
import scala.jdk.CollectionConverters._
sealed trait NetworkProtocol {
  def unwrap: software.amazon.awssdk.services.lightsail.model.NetworkProtocol
}
object NetworkProtocol {
  def wrap(
      value: software.amazon.awssdk.services.lightsail.model.NetworkProtocol
  ): zio.aws.lightsail.model.NetworkProtocol = value match {
    case software.amazon.awssdk.services.lightsail.model.NetworkProtocol.UNKNOWN_TO_SDK_VERSION =>
      val r = unknownToSdkVersion
      r
    case software.amazon.awssdk.services.lightsail.model.NetworkProtocol.TCP =>
      val r = tcp
      r
    case software.amazon.awssdk.services.lightsail.model.NetworkProtocol.ALL =>
      val r = all
      r
    case software.amazon.awssdk.services.lightsail.model.NetworkProtocol.UDP =>
      val r = udp
      r
    case software.amazon.awssdk.services.lightsail.model.NetworkProtocol.ICMP =>
      val r = icmp
      r
    case software.amazon.awssdk.services.lightsail.model.NetworkProtocol.ICMPV6 =>
      val r = icmpv6
      r
  }
  case object unknownToSdkVersion
      extends zio.aws.lightsail.model.NetworkProtocol {
    override def unwrap
        : software.amazon.awssdk.services.lightsail.model.NetworkProtocol =
      software.amazon.awssdk.services.lightsail.model.NetworkProtocol.UNKNOWN_TO_SDK_VERSION
  }
  case object tcp extends zio.aws.lightsail.model.NetworkProtocol {
    override def unwrap
        : software.amazon.awssdk.services.lightsail.model.NetworkProtocol =
      software.amazon.awssdk.services.lightsail.model.NetworkProtocol.TCP
  }
  case object all extends zio.aws.lightsail.model.NetworkProtocol {
    override def unwrap
        : software.amazon.awssdk.services.lightsail.model.NetworkProtocol =
      software.amazon.awssdk.services.lightsail.model.NetworkProtocol.ALL
  }
  case object udp extends zio.aws.lightsail.model.NetworkProtocol {
    override def unwrap
        : software.amazon.awssdk.services.lightsail.model.NetworkProtocol =
      software.amazon.awssdk.services.lightsail.model.NetworkProtocol.UDP
  }
  case object icmp extends zio.aws.lightsail.model.NetworkProtocol {
    override def unwrap
        : software.amazon.awssdk.services.lightsail.model.NetworkProtocol =
      software.amazon.awssdk.services.lightsail.model.NetworkProtocol.ICMP
  }
  case object icmpv6 extends zio.aws.lightsail.model.NetworkProtocol {
    override def unwrap
        : software.amazon.awssdk.services.lightsail.model.NetworkProtocol =
      software.amazon.awssdk.services.lightsail.model.NetworkProtocol.ICMPV6
  }
}
